@@ -1,12 +1,13 @@
 import os
 from distutils.util import strtobool
-from typing import Deque, Any, Optional
+from enum import Enum
+from typing import Deque, Any, Optional, Union
 
 from fastapi_events import event_store
 from fastapi_events.typing import Event
 
 
-def dispatch(event_name: str, payload: Optional[Any] = None) -> None:
+def dispatch(event_name: Union[str, Enum], payload: Optional[Any] = None) -> None:
     DISABLE_DISPATCH_GLOBALLY = strtobool(os.environ.get("FASTAPI_EVENTS_DISABLE_DISPATCH", "0"))
 
     if DISABLE_DISPATCH_GLOBALLY:
